psychopass-python |Build Status|
================================

A python password generator inspired by
`FlowerPassword <http://www.flowerpassword.com>`__.

.. |Build Status| image:: https://travis-ci.org/cissoid/psychopass-python.svg?branch=master
   :target: https://travis-ci.org/cissoid/psychopass-python
